@@ -2,18 +2,21 @@
 knitr::opts_chunk$set(
 	collapse = TRUE,
 	comment = "#>",
+  fig.width = 7,
+  fig.height = 5,
+	cache = FALSE,
 	eval = nzchar(Sys.getenv("COMPILE_VIG"))
 )
 library(cansim)
 
-## ---- eval = FALSE------------------------------------------------------------
-#  install.packages("cansim")
+## ----eval = FALSE-------------------------------------------------------------
+# install.packages("cansim")
 
 ## ----load_package_cran, echo=TRUE, message=FALSE, warning=FALSE, eval = FALSE----
-#  # install.packages("remotes")
-#  remotes::install_github("mountainmath/cansim")
-#  
-#  library(cansim)
+# # install.packages("remotes")
+# remotes::install_github("mountainmath/cansim")
+# 
+# library(cansim)
 
 ## -----------------------------------------------------------------------------
 data <- get_cansim("14-10-0293")
@@ -29,5 +32,6 @@ search_cansim_cubes("housing price indexes")
 get_cansim_vector(c("Metro Van Apartment Construction Price Index"="v44176267",
                     "Metro Van CPI"="v41692930"),
                   start_time = "2015-05-01",
-                  end_time="2015-08-01")
+                  end_time="2015-08-01") |>
+  dplyr::select(Date,GEO,label,VALUE,val_norm)
 
